==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/DEVICETOLERANCEVALUE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour DEVICETOLERANCEVALUE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DEVICETOLERANCEVALUE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEVICETOLERANCEFROM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEVICETOLERANCETO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEVICETOLERANCETYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DEVICETOLERANCEVALUE_Type", propOrder = {
    "devicetolerancefrom",
    "devicetoleranceto",
    "devicetolerancetype"
})
public class DEVICETOLERANCEVALUE_Type {

    @XmlElement(name = "DEVICETOLERANCEFROM", required = true)
    protected QUANTITY devicetolerancefrom;
    @XmlElement(name = "DEVICETOLERANCETO", required = true)
    protected QUANTITY devicetoleranceto;
    @XmlElement(name = "DEVICETOLERANCETYPE", required = true, defaultValue = "P")
    protected String devicetolerancetype;

    /**
     * Obtient la valeur de la propriété devicetolerancefrom.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDEVICETOLERANCEFROM() {
        return devicetolerancefrom;
    }

    /**
     * Définit la valeur de la propriété devicetolerancefrom.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDEVICETOLERANCEFROM(QUANTITY value) {
        this.devicetolerancefrom = value;
    }

    /**
     * Obtient la valeur de la propriété devicetoleranceto.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDEVICETOLERANCETO() {
        return devicetoleranceto;
    }

    /**
     * Définit la valeur de la propriété devicetoleranceto.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDEVICETOLERANCETO(QUANTITY value) {
        this.devicetoleranceto = value;
    }

    /**
     * Obtient la valeur de la propriété devicetolerancetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEVICETOLERANCETYPE() {
        return devicetolerancetype;
    }

    /**
     * Définit la valeur de la propriété devicetolerancetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEVICETOLERANCETYPE(String value) {
        this.devicetolerancetype = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/DEVICETOLERANCEVALUE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for DEVICETOLERANCEVALUE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DEVICETOLERANCEVALUE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEVICETOLERANCEFROM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEVICETOLERANCETO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEVICETOLERANCETYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DEVICETOLERANCEVALUE_Type", propOrder = {
    "devicetolerancefrom",
    "devicetoleranceto",
    "devicetolerancetype"
})
public class DEVICETOLERANCEVALUE_Type {

    @XmlElement(name = "DEVICETOLERANCEFROM", required = true)
    protected QUANTITY devicetolerancefrom;
    @XmlElement(name = "DEVICETOLERANCETO", required = true)
    protected QUANTITY devicetoleranceto;
    @XmlElement(name = "DEVICETOLERANCETYPE", required = true, defaultValue = "P")
    protected String devicetolerancetype;

    /**
     * Gets the value of the devicetolerancefrom property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDEVICETOLERANCEFROM() {
        return devicetolerancefrom;
    }

    /**
     * Sets the value of the devicetolerancefrom property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDEVICETOLERANCEFROM(QUANTITY value) {
        this.devicetolerancefrom = value;
    }

    /**
     * Gets the value of the devicetoleranceto property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDEVICETOLERANCETO() {
        return devicetoleranceto;
    }

    /**
     * Sets the value of the devicetoleranceto property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDEVICETOLERANCETO(QUANTITY value) {
        this.devicetoleranceto = value;
    }

    /**
     * Gets the value of the devicetolerancetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEVICETOLERANCETYPE() {
        return devicetolerancetype;
    }

    /**
     * Sets the value of the devicetolerancetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEVICETOLERANCETYPE(String value) {
        this.devicetolerancetype = value;
    }

}
